@@ -763,7 +763,7 @@ system( "/usr/bin/gnuplot list.plot" );
 
 
 
-double Falign( double **offsetmtx, double ***scoringmatrices, double **n_dynamicmtx,
+double Falign( int **whichmtx, double ***scoringmatrices, double **n_dynamicmtx,
 			  char  **seq1, char  **seq2, 
 			  double *eff1, double *eff2, 
 			  double **eff1s, double **eff2s,
@@ -826,7 +826,9 @@ double Falign( double **offsetmtx, double ***scoringmatrices, double **n_dynamic
 			alignableReagion( 0, 0, NULL, NULL, NULL, NULL, NULL );
 			fft( 0, NULL, 1 );
 			A__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+			D__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
 			A__align_variousdist( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+			D__align_variousdist( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
 			G__align11( NULL, NULL, NULL, 0, 0, 0 );
 			blockAlign2( NULL, NULL, NULL, NULL, NULL, NULL );
 			if( crossscore ) FreeDoubleMtx( crossscore );
@@ -1165,6 +1167,7 @@ system( "less seqVec2 < /dev/tty > /dev/tty" );
 
 
 
+
 #define CAND 0
 #if CAND
 	fftfp = fopen( "cand", "w" );
@@ -1514,6 +1517,21 @@ system( "less seqVec2 < /dev/tty > /dev/tty" );
 						totalscore += MSalignmm( n_dynamicmtx, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
 //						totalscore += MSalignmm( n_dis_consweight_multi, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
 				break;
+			case( 'd' ):
+				if( clus1 == 1 && clus2 == 1 )
+				{
+					totalscore += G__align11( n_dynamicmtx, tmpres1, tmpres2, alloclen, headgp, tailgp );
+				}
+				else
+				{
+					if( scoringmatrices ) // called by tditeration.c
+					{
+						totalscore += D__align_variousdist( whichmtx, scoringmatrices, NULL, tmpres1, tmpres2, eff1, eff2, eff1s, eff2s, clus1, clus2, alloclen, NULL, &dumdb, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
+					}
+					else
+					totalscore += D__align( n_dynamicmtx, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumdb, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
+				}
+				break;
 			case( 'A' ):
 				if( clus1 == 1 && clus2 == 1 )
 				{
@@ -1523,7 +1541,7 @@ system( "less seqVec2 < /dev/tty > /dev/tty" );
 				{
 					if( scoringmatrices ) // called by tditeration.c
 					{
-						totalscore += A__align_variousdist( NULL, scoringmatrices, NULL, tmpres1, tmpres2, eff1, eff2, eff1s, eff2s, clus1, clus2, alloclen, NULL, &dumdb, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
+						totalscore += A__align_variousdist( whichmtx, scoringmatrices, NULL, tmpres1, tmpres2, eff1, eff2, eff1s, eff2s, clus1, clus2, alloclen, NULL, &dumdb, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
 					}
 					else
 						totalscore += A__align( n_dynamicmtx, tmpres1, tmpres2, eff1, eff2, clus1, clus2, alloclen, NULL, &dumdb, sgap1, sgap2, egap1, egap2, chudanpt, chudanref, chudanres, headgp, tailgp );
@@ -1598,7 +1616,7 @@ system( "less seqVec2 < /dev/tty > /dev/tty" );
 sakujo wo kentou (2010/10/05)
 */
 double Falign_udpari_long( 
-			  double **offsetmtx, double ***scoringmatrices, 
+			  int **whichmtx, double ***scoringmatrices, 
 			  double **n_dynamicmtx,
 			  char  **seq1, char  **seq2, 
 			  double *eff1, double *eff2, 
@@ -1662,6 +1680,7 @@ double Falign_udpari_long(
 			fft( 0, NULL, 1 );
 			A__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
 			A__align_variousdist( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+			D__align_variousdist( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
 			G__align11( NULL, NULL, NULL, 0, 0, 0 );
 			blockAlign2( NULL, NULL, NULL, NULL, NULL, NULL );
 			if( crossscore ) FreeDoubleMtx( crossscore );
