@@ -45,7 +45,7 @@ static void seq_vec_2( Fukusosuu *result, double *score, double incr, char *seq
 	static TLS int n;
 	for( ; *seq; result++ )
 	{
-		n = amino_n[(int)*seq++];
+		n = amino_n[(unsigned char)*seq++];
 		if( n < 20 && n >= 0 ) result->R += incr * score[n];
 #if 0
 		fprintf( stderr, "n=%d, score=%f, inc=%f R=%f\n",n,  score[n], incr * score[n], result->R );
@@ -59,7 +59,7 @@ static void seq_vec_3( Fukusosuu **result, double incr, char *seq )
 	int n;
 	for( i=0; *seq; i++ )
 	{
-		n = amino_n[(int)*seq++];
+		n = amino_n[(unsigned char)*seq++];
 		if( n < n20or4or2 && n >= 0 ) result[n][i].R += incr;
 	}
 }
