@@ -13,10 +13,10 @@ static TLS int localstop; // 060910
 static void match_calc_mtx( double **mtx, double *match, char **s1, char **s2, int i1, int lgth2 ) 
 {
 	char *seq2 = s2[0];
-	double *doubleptr = mtx[(int)s1[0][i1]];
+	double *doubleptr = mtx[(unsigned char)s1[0][i1]];
 
 	while( lgth2-- )
-		*match++ = doubleptr[(int)*seq2++];
+		*match++ = doubleptr[(unsigned char)*seq2++];
 }
 #else
 static void match_calc( double *match, char **s1, char **s2, int i1, int lgth2 )
@@ -370,7 +370,7 @@ double L__align11( double **n_dynamicmtx, double scoreoffset, char **seq1, char
 #if DEBUG
 		fprintf( stderr, "succeeded\n" );
 #endif
-		amino_dynamicmtx = AllocateDoubleMtx( 0x80, 0x80 );
+		amino_dynamicmtx = AllocateDoubleMtx( 0x100, 0x100 );
 		orlgth1 = ll1 - 100;
 		orlgth2 = ll2 - 100;
 	}
