@@ -480,8 +480,8 @@ static void match_calc_del( int **which, double ***matrices, double *match, int
 			j = mask2[m];
 //			reporterr( "Deleting %d-%d (c=%d)\n", i, j, mid );
 //			if( k==0 ) fprintf( stderr, "pairoffset[%d][%d] = %f\n", i, j, po );
-			c1 = amino_n[(int)seq1[i][i1]];
-			c2 = amino_n[(int)seq2[j][k]];
+			c1 = amino_n[(unsigned int)seq1[i][i1]];
+			c2 = amino_n[(unsigned int)seq2[j][k]];
 //			reporterr( "k=%d, c1=%d, c2=%d, seq1[i][i1]=%c, seq2[%d][%d]=%c\n", k, c1, c2, seq1[i][i1], j, k, seq2[j][k] );
 			if( seq1[i][i1] == '-' || seq2[j][k] == '-' ) continue;
 			if( c1 < 0 || c2 < 0 ) continue;
@@ -519,8 +519,8 @@ static void match_calc_slow( int **which, double ***matrices, double *match, int
 			if( flip ) mid = which[j][i];
 			else       mid = which[i][j];
 //			if( k==0 ) fprintf( stderr, "pairoffset[%d][%d] = %f\n", i, j, po );
-			c1 = amino_n[(int)seq1[i][i1]];
-			c2 = amino_n[(int)seq2[j][k]];
+			c1 = amino_n[(unsigned int)seq1[i][i1]];
+			c2 = amino_n[(unsigned int)seq2[j][k]];
 			if( seq1[i][i1] == '-' || seq2[j][k] == '-' ) continue;
 			if( c1 < 0 || c2 < 0 ) continue;
 //			fprintf( stderr, "c1=%d, c2=%d\n", c1, c2 );
