@@ -19,6 +19,7 @@ static int keeplength;
 static int ndeleted;
 static int mapout;
 static int smoothing;
+static double hitout;
 
 static double lenfaca, lenfacb, lenfacc, lenfacd;
 static int tuplesize;
@@ -859,6 +860,8 @@ void arguments( int argc, char *argv[] )
 	keeplength = 0;
 	mapout = 0;
 	smoothing = 0;
+	distout = 0;
+	hitout = 0.0;
 
     while( --argc > 0 && (*++argv)[0] == '-' )
 	{
@@ -966,6 +969,10 @@ void arguments( int argc, char *argv[] )
 				case 'y':
 					distout = 1;
 					break;
+				case '^':
+					hitout = atof( *++argv );
+					--argc;
+					goto nextoption;
 				case 't':
 					treeout = 1;
 					break;
@@ -2570,22 +2577,60 @@ void ktupledistancematrix( int nseq, int norg, int nlenmax, char **seq, char **n
 	fprintf( stderr, "\ndone.\n\n" );
 	fflush( stderr );
 
-	for( i=0; i<norg; i++ )
-	{
-		for( j=i+1; j<norg; j++ ) 
-		{
-
-		}
-		for( j=norg; j<nseq; j++ ) 
-		{
-		}
-	}
 	free( grpseq );
 	free( tmpseq );
 	FreeIntMtx( pointt );
     free( nogaplen );
     free( selfscore );
 
+
+	if( hitout<0.0 )
+	{
+		fprintf( stdout, "Threshold=%f\n\n", -hitout );
+		for( i=0; i<norg; i++ )
+		{
+			for( j=norg; j<nseq; j++ ) 
+			{
+				if( nmtx[i][j-norg] < -hitout )
+					break;
+			}
+			if( j<nseq ) 
+			{
+				fprintf( stdout, "%s may be similar to:\n", name[i]+1 );
+				for( j=norg; j<nseq; j++ ) 
+				{
+					if( nmtx[i][j-norg] < -hitout )
+						fprintf( stdout, "    %s, %f\n", name[j]+1, nmtx[i][j-norg] );
+				}
+				fprintf( stdout, "\n" );
+			}
+		}
+		exit( 1 );
+	}
+	if( hitout>0.0 )
+	{
+		fprintf( stdout, "Threshold=%f\n\n", hitout );
+		for( i=norg; i<nseq; i++ )
+		{
+			for( j=0; j<norg; j++ ) 
+			{
+				if( nmtx[j][i-norg] < hitout )
+					break;
+			}
+			if( j<norg ) 
+			{
+				fprintf( stdout, "%s may be similar to:\n", name[i]+1 );
+				for( j=0; j<norg; j++ ) 
+				{
+					if( nmtx[j][i-norg] < hitout )
+						fprintf( stdout, "    %s, %f\n", name[j]+1, nmtx[j][i-norg] );
+				}
+				fprintf( stdout, "\n" );
+			}
+		}
+		exit( 1 );
+	}
+
 #if 0 // writehat2 wo kakinaosu
 	if( distout )
 	{
@@ -3080,7 +3125,7 @@ int main( int argc, char *argv[] )
 	alignmentlength = strlen( seq[0] );
 	for( i=0; i<norg; i++ )
 	{
-		if( alignmentlength != strlen( seq[i] ) )
+		if( hitout == 0.0 && alignmentlength != strlen( seq[i] ) )
 		{
 			fprintf( stderr, "#################################################################################\n" );
 			fprintf( stderr, "# ERROR!                                                                        #\n" );
