@@ -314,7 +314,7 @@ void BLOSUMmtx( int n, double **matrix, double *freq, char *amino, char *amino_g
     for( i=0; i<26; i++ ) amino_grp[(int)amino[i]] = locgrpd[i];
 }
 
-void extendedmtx( double **matrix, double *freq, char *amino, char *amino_grp )
+void extendedmtx( double **matrix, double *freq, unsigned char *amino, char *amino_grp )
 {
 	int i;
 	int j;
@@ -322,7 +322,7 @@ void extendedmtx( double **matrix, double *freq, char *amino, char *amino_grp )
 	for( i=0; i<nalphabets; i++ ) 
 	{
 //		fprintf( stderr, "i=%d, i=%c\n", i, i );
-		amino[i] = (char)i;
+		amino[i] = (unsigned char)i;
 	}
 	for( i=0; i<nalphabets; i++ ) amino_grp[(int)amino[i]] = i % 6;
 	for( i=0; i<nalphabets; i++ ) freq[i] = 1.0/nalphabets;
