@@ -150,7 +150,7 @@ static void calcfreq_extended( int nseq, char **seq, double *datafreq )
 		l = strlen( seq[i] );
 		for( j=0; j<l; j++ )
 		{
-			aan = amino_n[(int)seq[i][j]];
+			aan = amino_n[(unsigned char)seq[i][j]];
 			if( aan >= 0 && aan < nscoredalphabets && seq[i][j] != '-' )
 			{
 				datafreq[aan] += 1.0;
@@ -162,12 +162,14 @@ static void calcfreq_extended( int nseq, char **seq, double *datafreq )
 	for( i=0; i<nscoredalphabets; i++ ) datafreq[i] /= (double)total;
 //	for( i=0; i<nscoredalphabets; i++ ) if( datafreq[i] < 0.0001 ) datafreq[i] = 0.0001;
 
+#if 0
 	reporterr(       "datafreq = \n" );
 	for( i=0; i<nscoredalphabets; i++ )
-		reporterr(       "%f\n", datafreq[i] );
+		reporterr(       "%d %c %f\n", i, amino[i], datafreq[i] );
+#endif
 
 	total = 0.0; for( i=0; i<nscoredalphabets; i++ ) total += datafreq[i];
-	reporterr(       "total = %f\n", total );
+//	reporterr(       "total = %f\n", total );
 	for( i=0; i<nscoredalphabets; i++ ) datafreq[i] /= (double)total;
 }
 
@@ -203,6 +205,7 @@ void constants( int nseq, char **seq )
 	int i, j, x;
 //	double tmp;
 	char shiftmodel[100];
+	int charsize;
 
 	if( nblosum < 0 ) dorp = 'p';
 
@@ -219,6 +222,7 @@ void constants( int nseq, char **seq )
 
 		nalphabets = 26;
 		nscoredalphabets = 10;
+		charsize = 0x80;
 
 		n_dis = AllocateIntMtx( nalphabets, nalphabets );
 		n_disLN = AllocateDoubleMtx( nalphabets, nalphabets );
@@ -577,8 +581,9 @@ void constants( int nseq, char **seq )
 //		double tmp;
 		double **n_distmp;
 
-		nalphabets = 0x80;
-		nscoredalphabets = 0x80;
+		nalphabets = 0x100;
+		nscoredalphabets = 0x100;
+		charsize = 0x100;
 
 		reporterr(       "nalphabets = %d\n", nalphabets );
 
@@ -620,10 +625,10 @@ void constants( int nseq, char **seq )
 		for( i=0; i<0x80; i++ ) amino_n[i] = 0;
 		for( i=0; i<26; i++ ) amino_n[(int)amino[i]] = i;
 #endif
-		for( i=0; i<0x80; i++ )amino_n[i] = -1;
+		for( i=0; i<0x100; i++ )amino_n[i] = -1;
 		for( i=0; i<nalphabets; i++) 
 		{
-			amino_n[(int)amino[i]] = i;
+			amino_n[(unsigned char)amino[i]] = i;
 //			reporterr(       "i=%d, amino = %c, amino_n = %d\n", i, amino[i], amino_n[amino[i]] );
 		}
 		if( fmodel == 1 )
@@ -790,6 +795,7 @@ void constants( int nseq, char **seq )
 
 		nalphabets = 26;
 		nscoredalphabets = 20;
+		charsize = 0x80;
 
 		n_dis = AllocateIntMtx( nalphabets, nalphabets );
 		n_disLN = AllocateDoubleMtx( nalphabets, nalphabets );
@@ -990,6 +996,7 @@ void constants( int nseq, char **seq )
 
 		nalphabets = 26;
 		nscoredalphabets = 20;
+		charsize = 0x80;
 
 		n_dis = AllocateIntMtx( nalphabets, nalphabets );
 		n_disLN = AllocateDoubleMtx( nalphabets, nalphabets );
@@ -1299,11 +1306,16 @@ void constants( int nseq, char **seq )
 	reporterr(       "amino[] = %s\n", amino );
 #endif
 
-	for( i=0; i<0x80; i++ )amino_n[i] = -1;
+	amino_dis = AllocateIntMtx( charsize, charsize );
+	amino_dis_consweight_multi = AllocateDoubleMtx( charsize, charsize );
+
+	reporterr( "charsize=%d\n", charsize );
+
+	for( i=0; i<charsize; i++ )amino_n[i] = -1;
 	for( i=0; i<nalphabets; i++) amino_n[(int)amino[i]] = i;
-    for( i=0; i<0x80; i++ ) for( j=0; j<0x80; j++ ) amino_dis[i][j] = 0;
+    for( i=0; i<charsize; i++ ) for( j=0; j<charsize; j++ ) amino_dis[i][j] = 0;
     for( i=0; i<nalphabets; i++ ) for( j=0; j<nalphabets; j++ ) n_disLN[i][j] = 0;
-    for( i=0; i<0x80; i++ ) for( j=0; j<0x80; j++ ) amino_dis_consweight_multi[i][j] = 0.0;
+    for( i=0; i<charsize; i++ ) for( j=0; j<charsize; j++ ) amino_dis_consweight_multi[i][j] = 0.0;
 
 	n_dis_consweight_multi = AllocateDoubleMtx( nalphabets, nalphabets );
 	n_disFFT = AllocateIntMtx( nalphabets, nalphabets );
