@@ -13,17 +13,19 @@ int parallelizationstrategy = BAATARI1;
 
 char modelname[500];
 int njob, nlenmax;
-int amino_n[0x80];
-char amino_grp[0x80];
-int amino_dis[0x80][0x80];
+int amino_n[0x100];
+char amino_grp[0x100];
+//int amino_dis[0x100][0x100];
+int **amino_dis;
 double **n_disLN;
-double amino_dis_consweight_multi[0x80][0x80];
+//double amino_dis_consweight_multi[0x100][0x100];
+double **amino_dis_consweight_multi;
 int **n_dis;
 int **n_disFFT;
 double **n_dis_consweight_multi;
-char amino[0x80];
-double polarity[0x80];
-double volume[0x80];
+unsigned char amino[0x100];
+double polarity[0x100];
+double volume[0x100];
 int ribosumdis[37][37];
 
 int ppid;
