@@ -299,6 +299,9 @@ void arguments( int argc, char *argv[] )
 				case 'M':
 					alg = 'M';
 					break;
+				case '@':
+					alg = 'd';
+					break;
 				case 'F':
 					use_fft = 1;
 					break;
@@ -319,9 +322,11 @@ void arguments( int argc, char *argv[] )
 				case 'J':
 					utree = 0;
 					break;
+#if 0
 				case 'd':
 					disp = 1;
 					break;
+#endif
 				case 'Z':
 					score_check = 0;
 					break;
@@ -1020,6 +1025,7 @@ exit( 1 );
 	fprintf( stderr, "done\n" );
 	fprintf( trap_g, "done\n" );
 	fclose( trap_g );
+	freeconstants();
 
 
 	devide = 0; 
