@@ -169,7 +169,7 @@ extern void reduc( double **mtx, int nseq, int im, int jm );
 extern void  nj( int nseq, double **omtx, int ***topol, double **dis );
 extern void JTTmtx( double **rsr, double *freq, char locamino[0x80], char locgrp[0x80], int isTM );
 extern void BLOSUMmtx( int n, double **matrix, double *freq, char *amino, char *amino_grp );
-extern void extendedmtx( double **matrix, double *freq, char *amino, char *amino_grp );
+extern void extendedmtx( double **matrix, double *freq, unsigned char *amino, char *amino_grp );
 extern void putlocalhom2( char *al1, char *al2, LocalHom *localhompt, int off1, int off2, int opt, int overlapaa );
 extern void putlocalhom_str( char *al1, char *al2, double *equiv, double scale, LocalHom *localhompt, int off1, int off2, int opt, int overlapaa );
 extern void putlocalhom_ext( char *al1, char *al2, LocalHom *localhompt, int off1, int off2, int opt, int overlapaa );
