@@ -9,7 +9,7 @@
 static int maxl;
 static int tsize;
 static char outputformat;
-static float lenfaca, lenfacb, lenfacc, lenfacd;
+static double lenfaca, lenfacb, lenfacc, lenfacd;
 static int nadd;
 #define PLENFACA 0.01
 #define PLENFACB 10000
@@ -242,11 +242,11 @@ int main( int argc, char **argv )
 	static char **name;
 	static int *nlen;
 	double *mtxself;
-	float score;
+	double score;
 	static short *table1;
-	float longer, shorter;
-	float lenfac;
-	float bunbo;
+	double longer, shorter;
+	double lenfac;
+	double bunbo;
 	int norg;
 
 	arguments( argc, argv );
@@ -380,13 +380,13 @@ int main( int argc, char **argv )
 		{
 			if( nlen[i] > nlen[j] )
 			{
-				longer=(float)nlen[i];
-				shorter=(float)nlen[j];
+				longer=(double)nlen[i];
+				shorter=(double)nlen[j];
 			}
 			else
 			{
-				longer=(float)nlen[j];
-				shorter=(float)nlen[i];
+				longer=(double)nlen[j];
+				shorter=(double)nlen[i];
 			}
 //			lenfac = 3.0 / ( LENFACA + LENFACB / ( longer + LENFACC ) + shorter / longer * LENFACD );
 			lenfac = 1.0 / ( shorter / longer * lenfacd + lenfacb / ( longer + lenfacc ) + lenfaca );
