@@ -7,7 +7,7 @@
 #define END_OF_VEC -1
 
 int nadd;
-float thresholdtorev;
+double thresholdtorev;
 int dodp;
 int addfragment;
 
@@ -376,7 +376,7 @@ static void	*directionthread( void *arg )
 			mseq1[0] = tmpseq;
 			mseq2[0] = seq[j];
 //			res[j] = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1, mseq2, 0 );
-			res[j] = L__align11_noalign( mseq1, mseq2 );
+			res[j] = L__align11_noalign( n_dis_consweight_multi, mseq1, mseq2 );
 		}
 		else
 			res[j] = commonsextet_p2( table1, spointt[j] );
@@ -386,7 +386,7 @@ static void	*directionthread( void *arg )
 		free( mseq1 );
 		free( mseq2 );
 //		G__align11_noalign( NULL, 0, 0, NULL, NULL, 0 );
-		L__align11_noalign( NULL, NULL );
+		L__align11_noalign( NULL, NULL, NULL );
 	}
 //	else
 //		if( nthread )  // inthread == 0 no toki free suru to, error. nazeda
@@ -407,7 +407,7 @@ int main( int argc, char *argv[] )
 	int *grpseq;
 	char *tmpseq, *revseq;
 	int  **pointt, **pointt_rev, **spointt;
-	float res_forward, res_reverse, res_max;
+	double res_forward, res_reverse, res_max;
 	int ires, mres, mres2;
 	int *res;
 	static short *table1, *table1_rev;
@@ -515,8 +515,8 @@ int main( int argc, char *argv[] )
 //			res_forward = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1f, mseq2, 0 );
 //			res_reverse = G__align11_noalign( n_dis_consweight_multi, penalty, penalty_ex, mseq1r, mseq2, 0 );
 
-			res_forward = L__align11_noalign( mseq1f, mseq2 );
-			res_reverse = L__align11_noalign( mseq1r, mseq2 );
+			res_forward = L__align11_noalign( n_dis_consweight_multi, mseq1f, mseq2 );
+			res_reverse = L__align11_noalign( n_dis_consweight_multi, mseq1r, mseq2 );
 #if 0
 
 			strcpy( mseq2[0], seq[i] );
@@ -715,7 +715,7 @@ int main( int argc, char *argv[] )
 						mres2 = ires;
 				}
 			}
-			res_forward = (float)( mres + mres2 ) / 2;
+			res_forward = (double)( mres + mres2 ) / 2;
 
 #ifdef enablemultithread
 			if( nthread )
@@ -782,7 +782,7 @@ int main( int argc, char *argv[] )
 						mres2 = ires;
 				}
 			}
-			res_reverse = (float)( mres + mres2 ) / 2;
+			res_reverse = (double)( mres + mres2 ) / 2;
 
 //			fprintf( stdout, "\n" );
 //			fprintf( stdout, "score_for(%d,%d) = %f\n", 0, i, res_forward );
