@@ -36,7 +36,7 @@ static void readrawmccaskill( FILE *fp, RNApair **pairprob, int length )
 	int *pairnum;
 	int i;
 	int left, right;
-	float prob;
+	double prob;
 
 	pairnum = (int *)calloc( length, sizeof( int ) );
 	for( i=0; i<length; i++ ) pairnum[i] = 0;
@@ -46,7 +46,7 @@ static void readrawmccaskill( FILE *fp, RNApair **pairprob, int length )
 		fgets( gett, 999, fp );
 		if( feof( fp ) ) break;
 		if( gett[0] == '>' ) continue;
-		sscanf( gett, "%d %d %f", &left, &right, &prob );
+		sscanf( gett, "%d %d %lf", &left, &right, &prob );
 		if( prob < 0.01 ) continue; // mxscarna to mafft ryoho ni eikyou
 //fprintf( stderr, "gett = %s\n", gett );
 
@@ -229,7 +229,7 @@ int main( int argc, char *argv[] )
 	RNApair *pairprobpt;
 	RNApair *pt;
 	int *alnpairnum;
-	float prob;
+	double prob;
 	int adpos;
 
 	arguments( argc, argv );
@@ -439,7 +439,7 @@ int main( int argc, char *argv[] )
 
 	for( i=0; i<nlenmax; i++ ) for( pairprobpt=alnpairprob[i]; pairprobpt->bestpos!=-1; pairprobpt++ )
 	{
-		pairprobpt->bestscore /= (float)njob;
+		pairprobpt->bestscore /= (double)njob;
 		left = i;
 		right = pairprobpt->bestpos;
 		prob = pairprobpt->bestscore;
