@@ -129,11 +129,11 @@ void FreeCharMtx( char **mtx )
 	free( mtx );
 }
 
-float *AllocateFloatVec( int l1 )
+double *AllocateFloatVec( int l1 )
 {
-	float *vec;
+	double *vec;
 
-	vec = (float *)calloc( (unsigned int)l1, sizeof( float ) );
+	vec = (double *)calloc( (unsigned int)l1, sizeof( double ) );
 	if( vec == NULL )
 	{
 		fprintf( stderr, "Allocation error ( %d fload vec )\n", l1 );
@@ -142,17 +142,17 @@ float *AllocateFloatVec( int l1 )
 	return( vec );
 }
 
-void FreeFloatVec( float *vec )
+void FreeFloatVec( double *vec )
 {
 	free( (char *)vec );
 }
 
-float **AllocateFloatHalfMtx( int ll1 )
+double **AllocateFloatHalfMtx( int ll1 )
 {
-	float **mtx;
+	double **mtx;
 	int i;
 
-	mtx = (float **)calloc( (unsigned int)ll1+1, sizeof( float * ) );
+	mtx = (double **)calloc( (unsigned int)ll1+1, sizeof( double * ) );
 	if( mtx == NULL )
 	{
 		fprintf( stderr, "Allocation error ( %d fload halfmtx )\n", ll1 );
@@ -160,10 +160,10 @@ float **AllocateFloatHalfMtx( int ll1 )
 	}
 	for( i=0; i<ll1; i++ )
 	{
-		mtx[i] = (float *)calloc( ll1-i, sizeof( float ) );
+		mtx[i] = (double *)calloc( ll1-i, sizeof( double ) );
 		if( !mtx[i] )
 		{
-			fprintf( stderr, "Allocation error( %d floathalfmtx )\n", ll1 );
+			fprintf( stderr, "Allocation error( %d doublehalfmtx )\n", ll1 );
 			exit( 1 );
 		}
 	}
@@ -171,12 +171,12 @@ float **AllocateFloatHalfMtx( int ll1 )
 	return( mtx );
 }
 
-float **AllocateFloatMtx( int ll1, int ll2 )
+double **AllocateFloatMtx( int ll1, int ll2 )
 {
-	float **mtx;
+	double **mtx;
 	int i;
 
-	mtx = (float **)calloc( (unsigned int)ll1+1, sizeof( float * ) );
+	mtx = (double **)calloc( (unsigned int)ll1+1, sizeof( double * ) );
 	if( mtx == NULL )
 	{
 		fprintf( stderr, "Allocation error ( %d x %d fload mtx )\n", ll1, ll2 );
@@ -186,10 +186,10 @@ float **AllocateFloatMtx( int ll1, int ll2 )
 	{
 		for( i=0; i<ll1; i++ )
 		{
-			mtx[i] = (float *)calloc( ll2, sizeof( float ) );
+			mtx[i] = (double *)calloc( ll2, sizeof( double ) );
 			if( !mtx[i] )
 			{
-				fprintf( stderr, "Allocation error( %d x %d floatmtx )\n", ll1, ll2 );
+				fprintf( stderr, "Allocation error( %d x %d doublemtx )\n", ll1, ll2 );
 				exit( 1 );
 			}
 		}
@@ -198,7 +198,7 @@ float **AllocateFloatMtx( int ll1, int ll2 )
 	return( mtx );
 }
 
-void FreeFloatHalfMtx( float **mtx, int n )
+void FreeFloatHalfMtx( double **mtx, int n )
 {
 	int i;
 
@@ -208,7 +208,7 @@ void FreeFloatHalfMtx( float **mtx, int n )
 	}
 	free( mtx );
 }
-void FreeFloatMtx( float **mtx )
+void FreeFloatMtx( double **mtx )
 {
 	int i;
 
@@ -237,15 +237,15 @@ void FreeIntVec( int *vec )
 	free( (char *)vec );
 }
 
-float **AllocateFloatTri( int ll1 )
+double **AllocateFloatTri( int ll1 )
 {
-	float **tri;
+	double **tri;
 	int i;
 
-	tri = (float **)calloc( (unsigned int)ll1+1, sizeof( float * ) );
+	tri = (double **)calloc( (unsigned int)ll1+1, sizeof( double * ) );
 	if( !tri )
 	{
-		fprintf( stderr, "Allocation error ( float tri )\n" );
+		fprintf( stderr, "Allocation error ( double tri )\n" );
 		exit( 1 );
 	}
 	for( i=0; i<ll1; i++ ) 
@@ -257,10 +257,10 @@ float **AllocateFloatTri( int ll1 )
 	return( tri );
 }
 
-void FreeFloatTri( float **tri )
+void FreeFloatTri( double **tri )
 {
 /*
-	float **x;
+	double **x;
 	x = tri;
 	while( *tri != NULL ) free( *tri++ );
 	free( x );
@@ -455,15 +455,15 @@ void FreeDoubleMtx( double **mtx )
 	free( mtx );
 }
 
-float ***AllocateFloatCub( int ll1, int ll2, int  ll3 )
+double ***AllocateFloatCub( int ll1, int ll2, int  ll3 )
 {
 	int i;
-	float ***cub;
+	double ***cub;
 
-	cub = (float ***)calloc( ll1+1, sizeof( float ** ) );
+	cub = (double ***)calloc( ll1+1, sizeof( double ** ) );
 	if( !cub ) 
 	{
-		fprintf( stderr, "cannot allocate float cube.\n" );
+		fprintf( stderr, "cannot allocate double cube.\n" );
 		exit( 1 );
 	}
 	for( i=0; i<ll1; i++ ) 
@@ -474,7 +474,7 @@ float ***AllocateFloatCub( int ll1, int ll2, int  ll3 )
 	return( cub );
 }
 
-void FreeFloatCub( float ***cub )
+void FreeFloatCub( double ***cub )
 {
 	int i;
 
