@@ -8,16 +8,16 @@ char **AllocateCharMtx( int, int);
 void ReallocateCharMtx( char **, int, int);
 void FreeCharMtx( char ** );
 
-float *AllocateFloatVec( int );
-void FreeFloatVec( float * );
+double *AllocateFloatVec( int );
+void FreeFloatVec( double * );
 
-float **AllocateFloatHalfMtx( int );
-float **AllocateFloatMtx( int, int );
-void FreeFloatHalfMtx( float **, int );
-void FreeFloatMtx( float ** );
+double **AllocateFloatHalfMtx( int );
+double **AllocateFloatMtx( int, int );
+void FreeFloatHalfMtx( double **, int );
+void FreeFloatMtx( double ** );
 
-float **AlocateFloatTri( int );
-void FreeFloatTri( float ** );
+double **AlocateFloatTri( int );
+void FreeFloatTri( double ** );
 
 int *AllocateIntVec( int );
 void FreeIntVec( int * );
@@ -40,8 +40,8 @@ void FreeDoubleMtx( double ** );
 double ***AllocateDoubleCub( int, int, int );
 void FreeDoubleCub( double *** );
 
-float ***AllocateFloatCub( int, int, int );
-void FreeFloatCub( float *** );
+double ***AllocateFloatCub( int, int, int );
+void FreeFloatCub( double *** );
 
 short *AllocateShortVec( int );
 void FreeShortVec( short * );
