@@ -154,7 +154,7 @@ static void pairalign( char **name, int nlen[M], char **seq, double *effarr, int
 	static double *effarr2 = NULL;
 	static char **pseq;
 	LocalHom **localhomtable, *tmpptr;
-	float pscore = 0.0; // by D.Mathog, aguess
+	double pscore = 0.0; // by D.Mathog, aguess
 	char *aseq = NULL; // by D.Mathog
 	char **usedseqs = NULL; // by D.Mathog
 	char **usednames = NULL; // by D.Mathog
