@@ -329,12 +329,12 @@ static int checkcbeta( FILE *fp )
 }
 
 
-static float calltmalign( char **mseq1, char **mseq2, double *equiv, char *fname1, char *chain1, char *fname2, char *chain2, int alloclen )
+static double calltmalign( char **mseq1, char **mseq2, double *equiv, char *fname1, char *chain1, char *fname2, char *chain2, int alloclen )
 {
 	FILE *fp;
 	int res;
 	static char com[10000];
-	float value;
+	double value;
 	char cachedir[10000];
 	char cachefile[10000];
 	int runnow;
@@ -401,17 +401,17 @@ static float calltmalign( char **mseq1, char **mseq2, double *equiv, char *fname
 //	fprintf( stderr, "*mseq1 = %s\n", *mseq1 );
 //	fprintf( stderr, "*mseq2 = %s\n", *mseq2 );
 
-	value = (float)naivepairscore11( *mseq1, *mseq2, penalty );
+	value = (double)naivepairscore11( *mseq1, *mseq2, penalty );
 
 	return( value );
 }
 
-static float callrash( int mem1, int mem2, char **mseq1, char **mseq2, double *equiv, char *fname1, char *fname2, int alloclen )
+static double callrash( int mem1, int mem2, char **mseq1, char **mseq2, double *equiv, char *fname1, char *fname2, int alloclen )
 {
 	FILE *fp;
 //	int res;
 	static char com[10000];
-	float value;
+	double value;
 	char cachedir[10000];
 	char cachefile[10000];
 	int runnow;
@@ -507,7 +507,7 @@ static float callrash( int mem1, int mem2, char **mseq1, char **mseq2, double *e
 //	fprintf( stderr, "*mseq2 = %s\n", *mseq2 );
 
 
-	value = (float)naivepairscore11( *mseq1, *mseq2, penalty );
+	value = (double)naivepairscore11( *mseq1, *mseq2, penalty );
 
 	return( value );
 }
@@ -522,7 +522,7 @@ static void preparetmalign( FILE *fp, char ***strfiles, char ***chainids, char *
 	int linenum, istr, nstr;
 	FILE *checkfp;
 	char *sline; 
-	int use[1000];
+	int use[10000];
 	linenum = 0;
 	nstr = 0;
 	while( 1 )
@@ -629,7 +629,7 @@ static void prepareash( FILE *fp, char *inputfile, char ***strfiles, char ***cha
 	int linenum, istr, nstr;
 //	FILE *checkfp;
 	char *sline; 
-	int use[1000];
+	int use[10000];
 	linenum = 0;
 	nstr = 0;
 
@@ -1026,7 +1026,7 @@ static void pairalign( char **name, int nlen[M], char **seq, char **aseq, char *
 	int i, j, ilim;
 	int clus1, clus2;
 	int off1, off2;
-	float pscore = 0.0; // by D.Mathog
+	double pscore = 0.0; // by D.Mathog
 	static char *indication1, *indication2;
 	FILE *hat2p, *hat3p;
 	static double **distancemtx;
