@@ -190,7 +190,7 @@ static void putlocalhom_last( char *s1, char *s2, LocalHom *localhompt, Lastresx
 			iscore = 0;
 			while( len-- )
 			{
-				iscore += n_dis[(int)amino_n[(int)*pt1++]][(int)amino_n[(int)*pt2++]]; // - offset $B$O$$$i$J$$$+$b(B
+				iscore += n_dis[(int)amino_n[(unsigned char)*pt1++]][(int)amino_n[(unsigned char)*pt2++]]; // - offset $B$O$$$i$J$$$+$b(B
 //				fprintf( stderr, "len=%d, %c-%c, iscore(0) = %d\n", len, *(pt1-1), *(pt2-1), iscore );
 			}
 	
@@ -2477,7 +2477,7 @@ static void pairalign( char **name, int *nlen, char **seq, char **aseq, char **d
 	{
 		pscore = 0.0;
 		for( pt=seq[i]; *pt; pt++ )
-			pscore += amino_dis[(int)*pt][(int)*pt];
+			pscore += amino_dis[(unsigned char)*pt][(unsigned char)*pt];
 		selfscore[i] = pscore;
 //		fprintf( stderr, "selfscore[%d] = %f\n", i, selfscore[i] );
 	}
