@@ -528,6 +528,43 @@ static void fillzero( double *s, int l )
 	while( l-- ) *s++ = 0.0;
 }
 
+
+static void match_calc_del( int **which, double ***matrices, double *match, int n1, char **seq1, double *eff1, int n2, char **seq2, double *eff2, int i1, int lgth2, int mid, int nmask, int *mask1, int *mask2 ) 
+{
+// osoi!
+	int i, j, k, m;
+	int c1, c2;
+//	fprintf( stderr, "\nmatch_calc_dynamicmtx... %d", i1 );
+//	fprintf( stderr, "\nseq1[0]=%s\n", seq1[0] );
+//	fprintf( stderr, "\nseq2[0]=%s\n", seq2[0] );
+//	for( i=0; i<n1; i++ ) for( j=0; j<n2; j++ )
+//	{
+//		if( flip ) reporterr( "in match_calc_slow, which[%d][%d] = %d\n", j, i, which[j][i] );
+//		else       reporterr( "in match_calc_slow, which[%d][%d] = %d\n", i, j, which[i][j] );
+//	}
+	for( k=0; k<lgth2; k++ )
+	{
+		for( m=0; m<nmask; m++ )
+		{
+			i = mask1[m];
+			j = mask2[m];
+//			reporterr( "Deleting %d-%d (c=%d)\n", i, j, mid );
+//			if( k==0 ) fprintf( stderr, "pairoffset[%d][%d] = %f\n", i, j, po );
+			c1 = amino_n[(int)seq1[i][i1]];
+			c2 = amino_n[(int)seq2[j][k]];
+//			reporterr( "k=%d, c1=%d, c2=%d, seq1[i][i1]=%c, seq2[%d][%d]=%c\n", k, c1, c2, seq1[i][i1], j, k, seq2[j][k] );
+			if( seq1[i][i1] == '-' || seq2[j][k] == '-' ) continue;
+			if( c1 < 0 || c2 < 0 ) continue;
+//			fprintf( stderr, "c1=%d, c2=%d\n", c1, c2 );
+//			fprintf( stderr, "match[k] = %f -> ", match[k], mid );
+			match[k] -= matrices[mid][c1][c2] * eff1[i] * eff2[j];
+//			fprintf( stderr, "match[k] = %f (mid=%d)\n", match[k], mid );
+		}
+	}
+//	fprintf( stderr, "done\n" );
+	return;
+}
+
 static void match_calc_add( double **scoreingmtx, double *match, double **cpmx1, double **cpmx2, int i1, int lgth2, double **doublework, int **intwork, int initialize )
 {
 #if FASTMATCHCALC
@@ -1605,7 +1642,7 @@ fprintf( stderr, "\n" );
 	return( wm );
 }
 
-double partA__align_variousdist( double **pairoffset, double ***matrices, double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, double **eff1s, double **eff2s, int icyc, int jcyc, int alloclen, LocalHom ***localhom, double *impmatch, int start1, int end1, int start2, int end2, int *gapmap1, int *gapmap2, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres )
+double partA__align_variousdist( int **which, double ***matrices, double **n_dynamicmtx, char **seq1, char **seq2, double *eff1, double *eff2, double **eff1s, double **eff2s, int icyc, int jcyc, int alloclen, LocalHom ***localhom, double *impmatch, int start1, int end1, int start2, int end2, int *gapmap1, int *gapmap2, char *sgap1, char *sgap2, char *egap1, char *egap2, int *chudanpt, int chudanref, int *chudanres )
 /* score no keisan no sai motokaraaru gap no atukai ni mondai ga aru */
 {
 //	int k;
@@ -1672,6 +1709,7 @@ double partA__align_variousdist( double **pairoffset, double ***matrices, double
 	double curm = 0.0;
 	double *wmrecordspt, *wmrecords1pt, *prevwmrecordspt;
 	int *warpipt, *warpjpt;
+	int *nmask, **masklist1, **masklist2;
 
 
 	if( seq1 == NULL )
@@ -1720,6 +1758,31 @@ double partA__align_variousdist( double **pairoffset, double ***matrices, double
 		return( 0.0 );
 	}
 
+	masklist1 = AllocateIntMtx( maxdistclass, 0 );
+	masklist2 = AllocateIntMtx( maxdistclass, 0 );
+	nmask = calloc( maxdistclass, sizeof( int ) );
+
+	for( c=0; c<maxdistclass; c++ )
+	{
+		for( i=0; i<icyc; i++ ) for( j=0; j<jcyc; j++ )
+		{
+			if( eff1s[c][i] * eff2s[c][j] != 0.0 )
+			{
+
+				if( c != which[i][j] )
+				{
+					masklist1[c] = realloc( masklist1[c], sizeof( int ) * nmask[c]+1 );
+					masklist2[c] = realloc( masklist2[c], sizeof( int ) * nmask[c]+1 );
+
+					masklist1[c][nmask[c]] = i;
+					masklist2[c][nmask[c]] = j;
+					nmask[c]++;
+				}
+			}
+		}
+	}
+	for( c=0; c<maxdistclass; c++ ) if( nmask[c] ) break;
+	if( c<maxdistclass ) reporterr( "Found a complex grouping. Use an ultrametric tree to make the calculation faster.\n" );
 
 	lgth1 = strlen( seq1[0] );
 	lgth2 = strlen( seq2[0] );
@@ -1972,7 +2035,10 @@ double partA__align_variousdist( double **pairoffset, double ***matrices, double
 //	match_calc( initverticalw, cpmx2, cpmx1, 0, lgth1, doublework, intwork, 1 );
 	fillzero( initverticalw, lgth1 );
 	for( c=0; c<maxdistclass; c++ )
+	{
 		match_calc_add( matrices[c], initverticalw, cpmx2s[c], cpmx1s[c], 0, lgth1, doublework[c], intwork[c], 1 );
+		if( nmask[c] ) match_calc_del( which, matrices, initverticalw, jcyc, seq2, eff2, icyc, seq1, eff1, 0, lgth1, c, nmask[c], masklist2[c], masklist1[c] );
+	}
 
 	if( localhom )
 		part_imp_match_out_vead_tate_gapmap( initverticalw, gapmap2[0]+start2, lgth1, start1, gapmap1 );
@@ -1981,7 +2047,10 @@ double partA__align_variousdist( double **pairoffset, double ***matrices, double
 //	match_calc( currentw, cpmx1, cpmx2, 0, lgth2, doublework, intwork, 1 );
 	fillzero( currentw, lgth2 );
 	for( c=0; c<maxdistclass; c++ )
+	{
 		match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], 0, lgth2, doublework[c], intwork[c], 1 );
+		if( nmask[c] ) match_calc_del( which, matrices, currentw, icyc, seq1, eff1, jcyc, seq2, eff2, 0, lgth2, c, nmask[c], masklist1[c], masklist2[c] );
+	}
 	if( localhom )
 		part_imp_match_out_vead_gapmap( currentw, gapmap1[0]+start1, lgth2, start2, gapmap2 );
 #if 0 // -> tbfast.c
@@ -2053,6 +2122,9 @@ for( i=0; i<lgth2; i++ )
 		{
 //			fprintf( stderr, "\n\n## CHUUDAN!!! i\n" );
 			*chudanres = 1;
+			if( masklist1 ) FreeIntMtx( masklist1 ); masklist1 = NULL;
+			if( masklist2 ) FreeIntMtx( masklist2 ); masklist2 = NULL;
+			if( nmask ) free( nmask ); nmask = NULL;
 			return( -1.0 );
 		}
 #endif
@@ -2066,7 +2138,10 @@ for( i=0; i<lgth2; i++ )
 //		match_calc( currentw, cpmx1, cpmx2, i, lgth2, doublework, intwork, 0 );
 		fillzero( currentw, lgth2 );
 		for( c=0; c<maxdistclass; c++ )
+		{
 			match_calc_add( matrices[c], currentw, cpmx1s[c], cpmx2s[c], i, lgth2, doublework[c], intwork[c], 0 );
+			if( nmask[c] ) match_calc_del( which, matrices, currentw, icyc, seq1, eff1, jcyc, seq2, eff2, i, lgth2, c, nmask[c], masklist1[c], masklist2[c] );
+		}
 #if 0
 fprintf( stderr, "\n" );
 fprintf( stderr, "i=%d\n", i );
@@ -2130,6 +2205,9 @@ fprintf( stderr, "\n" );
 			{
 //				fprintf( stderr, "\n\n## CHUUDAN!!! j\n" );
 				*chudanres = 1;
+				if( masklist1 ) FreeIntMtx( masklist1 ); masklist1 = NULL;
+				if( masklist2 ) FreeIntMtx( masklist2 ); masklist2 = NULL;
+				if( nmask ) free( nmask ); nmask = NULL;
 				return( -1.0 );
 			}
 #endif
@@ -2297,6 +2375,9 @@ fprintf( stderr, "\n" );
 	for( j=0; j<jcyc; j++ ) fprintf( stderr, "%s\n", mseq2[j] );
 	*/
 
+	if( masklist1 ) FreeIntMtx( masklist1 ); masklist1 = NULL;
+	if( masklist2 ) FreeIntMtx( masklist2 ); masklist2 = NULL;
+	if( nmask ) free( nmask ); nmask = NULL;
 
 	return( wm );
 }
