@@ -10,9 +10,9 @@
 
 
 #if 0
-static float singleribosumscore( int n1, int n2, char **s1, char **s2, double *eff1, double *eff2, int p1, int p2 )
+static double singleribosumscore( int n1, int n2, char **s1, char **s2, double *eff1, double *eff2, int p1, int p2 )
 {
-	float val;
+	double val;
 	int i, j;
 	int code1, code2;
 
@@ -24,15 +24,15 @@ static float singleribosumscore( int n1, int n2, char **s1, char **s2, double *e
 		code2 = amino_n[(int)s2[j][p2]];
 		if( code2 > 3 ) code2 = 36;
 
-//		fprintf( stderr, "'l'%c-%c: %f\n", s1[i][p1], s2[j][p2], (float)ribosumdis[code1][code2] );
+//		fprintf( stderr, "'l'%c-%c: %f\n", s1[i][p1], s2[j][p2], (double)ribosumdis[code1][code2] );
 
-		val += (float)ribosumdis[code1][code2] * eff1[i] * eff2[j];
+		val += (double)ribosumdis[code1][code2] * eff1[i] * eff2[j];
 	}
 	return( val );
 }
-static float pairedribosumscore53( int n1, int n2, char **s1, char **s2, double *eff1, double *eff2, int p1, int p2, int c1, int c2 )
+static double pairedribosumscore53( int n1, int n2, char **s1, char **s2, double *eff1, double *eff2, int p1, int p2, int c1, int c2 )
 {
-	float val;
+	double val;
 	int i, j;
 	int code1o, code1u, code2o, code2u, code1, code2;
 
@@ -52,19 +52,19 @@ static float pairedribosumscore53( int n1, int n2, char **s1, char **s2, double
 		else code2 = 4 + code2o * 4 + code2u;
 
 
-//		fprintf( stderr, "%c%c-%c%c: %f\n", s1[i][p1], s1[i][c1], s2[j][p2], s2[j][c2], (float)ribosumdis[code1][code2] );
+//		fprintf( stderr, "%c%c-%c%c: %f\n", s1[i][p1], s1[i][c1], s2[j][p2], s2[j][c2], (double)ribosumdis[code1][code2] );
 
 		if( code1 == 36 || code2 == 36 )
-			val += (float)n_dis[code1o][code2o] * eff1[i] * eff2[j];
+			val += (double)n_dis[code1o][code2o] * eff1[i] * eff2[j];
 		else
-			val += (float)ribosumdis[code1][code2] * eff1[i] * eff2[j];
+			val += (double)ribosumdis[code1][code2] * eff1[i] * eff2[j];
 	}
 	return( val );
 }
 
-static float pairedribosumscore35( int n1, int n2, char **s1, char **s2, double *eff1, double *eff2, int p1, int p2, int c1, int c2 )
+static double pairedribosumscore35( int n1, int n2, char **s1, char **s2, double *eff1, double *eff2, int p1, int p2, int c1, int c2 )
 {
-	float val;
+	double val;
 	int i, j;
 	int code1o, code1u, code2o, code2u, code1, code2;
 
@@ -84,12 +84,12 @@ static float pairedribosumscore35( int n1, int n2, char **s1, char **s2, double
 		else code2 = 4 + code2u * 4 + code2o;
 
 
-//		fprintf( stderr, "%c%c-%c%c: %f\n", s1[i][p1], s1[i][c1], s2[j][p2], s2[j][c2], (float)ribosumdis[code1][code2] );
+//		fprintf( stderr, "%c%c-%c%c: %f\n", s1[i][p1], s1[i][c1], s2[j][p2], s2[j][c2], (double)ribosumdis[code1][code2] );
 
 		if( code1 == 36 || code2 == 36 )
-			val += (float)n_dis[code1o][code2o] * eff1[i] * eff2[j];
+			val += (double)n_dis[code1o][code2o] * eff1[i] * eff2[j];
 		else
-			val += (float)ribosumdis[code1][code2] * eff1[i] * eff2[j];
+			val += (double)ribosumdis[code1][code2] * eff1[i] * eff2[j];
 	}
 	return( val );
 }
@@ -102,7 +102,7 @@ static void mccaskillextract( char **seq, char **nogap, int nseq, RNApair **pair
 	int nogaplgth;
 	int i, j;
 	int left, right, adpos;
-	float prob;
+	double prob;
 	static TLS int *pairnum;
 	RNApair *pt, *pt2;
 
@@ -156,7 +156,7 @@ static void mccaskillextract( char **seq, char **nogap, int nseq, RNApair **pair
 	{
 		if( pairprob[i][j].bestpos > -1 )
 		{
-//			pairprob[i][j].bestscore /= (float)nseq;
+//			pairprob[i][j].bestscore /= (double)nseq;
 //			fprintf( stderr, "pair of %d = %d (%f) %c:%c\n", i, pairprob[i][j].bestpos, pairprob[i][j].bestscore, seq[0][i], seq[0][pairprob[i][j].bestpos] );
 		}
 	}
@@ -190,7 +190,7 @@ void rnaalifoldcall( char **seq, int nseq, RNApair **pairprob )
 	char gett[1000];
 	FILE *fp;
 	int left, right, dumm;
-	float prob;
+	double prob;
 	static TLS int pid;
 	static TLS char fnamein[100];
 	static TLS char cmd[1000];
@@ -249,7 +249,7 @@ void rnaalifoldcall( char **seq, int nseq, RNApair **pairprob )
 		if( gett[0] == ',' ) break;
 		if( gett[0] != ' ' ) continue;
 
-		sscanf( gett, "%d %d %d %f", &left, &right, &dumm, &prob );
+		sscanf( gett, "%d %d %d %lf", &left, &right, &dumm, &prob );
 		left--;
 		right--;
 
@@ -327,7 +327,7 @@ static void utot( int n, int l, char **s )
 }
 
 
-void foldrna( int nseq1, int nseq2, char **seq1, char **seq2, double *eff1, double *eff2, RNApair ***grouprna1, RNApair ***grouprna2, float **impmtx, int *gapmap1, int *gapmap2, RNApair *additionalpair )
+void foldrna( int nseq1, int nseq2, char **seq1, char **seq2, double *eff1, double *eff2, RNApair ***grouprna1, RNApair ***grouprna2, double **impmtx, int *gapmap1, int *gapmap2, RNApair *additionalpair )
 {
 	int i, j;
 //	int ui, uj;
@@ -339,13 +339,13 @@ void foldrna( int nseq1, int nseq2, char **seq1, char **seq2, double *eff1, doub
 	static TLS RNApair *pairpt1, *pairpt2;
 	int lgth1 = strlen( seq1[0] );
 	int lgth2 = strlen( seq2[0] );
-	static TLS float **impmtx2;
-	static TLS float **map;
+	static TLS double **impmtx2;
+	static TLS double **map;
 //	double lenfac;
-	float prob;
+	double prob;
 	int **sgapmap1, **sgapmap2;
 //	char *nogapdum;
-	float **tbppmtx;
+	double **tbppmtx;
 
 
 //	fprintf( stderr, "nseq1=%d, lgth1=%d\n", nseq1, lgth1 );
