@@ -320,6 +320,9 @@ void arguments( int argc, char *argv[] )
 					alg = 'Q';
 					break;
 #endif
+				case '@':
+					alg = 'd';
+					break;
 				case 'A':
 					alg = 'A';
 					break;
@@ -619,6 +622,7 @@ static void *treebasethread( void *arg )
 			Falign( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
 			Falign_udpari_long( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL );
 			A__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+			D__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
 			free( mseq1 );
 			free( mseq2 );
 			free( localcopy );
@@ -816,6 +820,12 @@ static void *treebasethread( void *arg )
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
 				pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
+			if( alg == 'd' )
+			{
+				imp_match_init_strictD( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
+				if( rnakozo ) imp_rnaD( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
+				pscore = D__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+			}
 			else if( alg == 'Q' )
 			{
 				fprintf( stderr, "Not supported\n" );
@@ -849,6 +859,9 @@ static void *treebasethread( void *arg )
 				case( 'A' ):
 					pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
+				case( 'd' ):
+					pscore = D__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					break;
 				default:
 					ErrorExit( "ERROR IN SOURCE FILE" );
 			}
@@ -906,17 +919,17 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 	int len1, len2;
 	int clus1, clus2;
 	double pscore, tscore;
-	static char *indication1, *indication2;
-	static double *effarr1 = NULL;
-	static double *effarr2 = NULL;
-	static double *effarr1_kozo = NULL;
-	static double *effarr2_kozo = NULL;
-	static LocalHom ***localhomshrink = NULL;
-	static int *fftlog;
+	char *indication1, *indication2;
+	double *effarr1 = NULL;
+	double *effarr2 = NULL;
+	double *effarr1_kozo = NULL;
+	double *effarr2_kozo = NULL;
+	LocalHom ***localhomshrink = NULL;
+	int *fftlog;
 	int m1, m2;
-	static int *gaplen;
-	static int *gapmap;
-	static int *alreadyaligned;
+	int *gaplen;
+	int *gapmap;
+	int *alreadyaligned;
 //	double dumfl = 0.0;
 	double dumdb = 0.0;
 	int ffttry;
@@ -934,31 +947,28 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 		grouprna1 = grouprna2 = NULL;
 	}
 
-	if( effarr1 == NULL ) 
-	{
-		fftlog = AllocateIntVec( njob );
-		effarr1 = AllocateDoubleVec( njob );
-		effarr2 = AllocateDoubleVec( njob );
-		indication1 = AllocateCharVec( 150 );
-		indication2 = AllocateCharVec( 150 );
-		gaplen = AllocateIntVec( *alloclen+10 );
-		gapmap = AllocateIntVec( *alloclen+10 );
-		alreadyaligned = AllocateIntVec( njob );
-		dynamicmtx = AllocateDoubleMtx( nalphabets, nalphabets );
+	fftlog = AllocateIntVec( njob );
+	effarr1 = AllocateDoubleVec( njob );
+	effarr2 = AllocateDoubleVec( njob );
+	indication1 = AllocateCharVec( 150 );
+	indication2 = AllocateCharVec( 150 );
+	gaplen = AllocateIntVec( *alloclen+10 );
+	gapmap = AllocateIntVec( *alloclen+10 );
+	alreadyaligned = AllocateIntVec( njob );
+	dynamicmtx = AllocateDoubleMtx( nalphabets, nalphabets );
 #if 0
 #else
-		if( constraint )
-		{
-			localhomshrink = (LocalHom ***)calloc( njob, sizeof( LocalHom ** ) );
-			for( i=0; i<njob; i++ )
-				localhomshrink[i] = (LocalHom **)calloc( njob, sizeof( LocalHom *) );
-		}
-#endif
-		effarr1_kozo = AllocateDoubleVec( njob ); //tsuneni allocate sareru.
-		effarr2_kozo = AllocateDoubleVec( njob ); //tsuneni allocate sareru.
-		for( i=0; i<njob; i++ ) effarr1_kozo[i] = 0.0;
-		for( i=0; i<njob; i++ ) effarr2_kozo[i] = 0.0;
+	if( constraint )
+	{
+		localhomshrink = (LocalHom ***)calloc( njob, sizeof( LocalHom ** ) );
+		for( i=0; i<njob; i++ )
+			localhomshrink[i] = (LocalHom **)calloc( njob, sizeof( LocalHom *) );
 	}
+#endif
+	effarr1_kozo = AllocateDoubleVec( njob ); //tsuneni allocate sareru.
+	effarr2_kozo = AllocateDoubleVec( njob ); //tsuneni allocate sareru.
+	for( i=0; i<njob; i++ ) effarr1_kozo[i] = 0.0;
+	for( i=0; i<njob; i++ ) effarr2_kozo[i] = 0.0;
 
 	for( i=0; i<njob-nadd; i++ ) alreadyaligned[i] = 1;
 	for( i=njob-nadd; i<njob; i++ ) alreadyaligned[i] = 0;
@@ -1138,6 +1148,12 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 				if( rnakozo ) imp_rna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
 				pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 			}
+			if( alg == 'd' )
+			{
+				imp_match_init_strictD( NULL, clus1, clus2, strlen( mseq1[0] ), strlen( mseq2[0] ), mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
+				if( rnakozo ) imp_rnaD( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, NULL, NULL, NULL );
+				pscore = D__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, localhomshrink, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+			}
 			else if( alg == 'Q' )
 			{
 				fprintf( stderr, "Not supported\n" );
@@ -1171,6 +1187,9 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 				case( 'A' ):
 					pscore = A__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
 					break;
+				case( 'd' ):
+					pscore = D__align( dynamicmtx, mseq1, mseq2, effarr1, effarr2, clus1, clus2, *alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, outgap, outgap );
+					break;
 				default:
 					ErrorExit( "ERROR IN SOURCE FILE" );
 			}
@@ -1234,6 +1253,7 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 		free( topol[l][1] );
 		free( topol[l] );
 	}
+	free( topol[l] );
 #if SCOREOUT
 	fprintf( stderr, "totalscore = %10.2f\n\n", tscore );
 #endif
@@ -1256,6 +1276,25 @@ void treebase( int *nlen, char **aseq, int nadd, char *mergeoralign, char **mseq
 			localhomshrink = NULL;
 		}
 	}
+
+	free( topol );
+	free( fftlog );
+	free( effarr1 );
+	free( effarr2 );
+	free( indication1 );
+	free( indication2 );
+	free( gaplen );
+	free( gapmap );
+	free( alreadyaligned );
+	FreeDoubleMtx( dynamicmtx );
+	free( effarr1_kozo );
+	free( effarr2_kozo );
+	D__align( NULL,  NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+	A__align( NULL,  NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+	imp_match_init_strictD( NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0 );
+	imp_match_init_strict( NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0 );
+	freeconstants();
+	FreeCommonIP();
 }
 
 static void WriteOptions( FILE *fp )
@@ -2241,8 +2280,11 @@ int main( int argc, char *argv[] )
 #endif
 
 	fprintf( trap_g, "done.\n" );
-	fclose( trap_g );
+//	fclose( trap_g );
 	free( mergeoralign );
+
+
+
 	if( rnakozo && rnaprediction == 'm' ) 
 	{
 		if( singlerna ) // nen no tame
@@ -2272,6 +2314,8 @@ int main( int argc, char *argv[] )
 
 	if( constraint ) FreeLocalHomTable( localhomtable, njob );
 
+
+
 	if( spscoreout ) reporterr( "Unweighted sum-of-pairs score = %10.5f\n", sumofpairsscore( njob, bseq ) );
 	SHOWVERSION;
 	if( ndeleted > 0 )
@@ -2282,5 +2326,30 @@ int main( int argc, char *argv[] )
 		else
 			reporterr( "To know the positions of deleted letters, rerun the same command with the --mapout option.\n" );
 	}
+
+
+	free( kozoarivec );
+	FreeCharMtx( seq );
+	FreeCharMtx( bseq );
+	free( mseq1 );
+	free( mseq2 );
+
+	FreeCharMtx( name );
+	free( nlen );
+	free( selfscore );
+
+//	for( i=0; i<njob; i++ ) 
+//	{
+//		free( topol[i][0] );
+//		free( topol[i][1] );
+//		free( topol[i] );
+//	}
+//	free( topol );
+//	free( len );
+//	free( iscore );
+	free( eff );
+	free( dep );
+	closeFiles();
+
 	return( 0 );
 }
