@@ -137,7 +137,7 @@ void cpmx_calc( char **seq, double **cpmx, double *eff, int lgth, int clus )
 	for( i=0; i<clus; i++ ) totaleff += eff[i]; 
 	for( i=0; i<nalphabets; i++ ) for( j=0; j<lgth; j++ ) cpmx[i][j] = 0.0;
 	for( j=0; j<lgth; j++ ) for( k=0; k<clus; k++ )
-			cpmx[(int)amino_n[(int)seq[k][j]]][j] += (double)eff[k] / totaleff;
+			cpmx[(int)amino_n[(unsigned char)seq[k][j]]][j] += (double)eff[k] / totaleff;
 }
 
 
@@ -180,7 +180,7 @@ void cpmx_calc_new( char **seq, double **cpmx, double *eff, int lgth, int clus )
 //		fprintf( stderr, "seqpt = %s, lgth=%d\n", seqpt, lgth );
 		for( j=0; j<lgth; j++ )
 		{
-			cpmx[(int)amino_n[(int)*seqpt++]][j] += feff;
+			cpmx[(unsigned char)amino_n[(unsigned char)*seqpt++]][j] += feff;
 		}
 	}
 }
@@ -207,7 +207,7 @@ void MScpmx_calc_new( char **seq, double **cpmx, double *eff, int lgth, int clus
 		cpmxptpt = cpmx;
 		j = lgth;
 		while( j-- )
-			(*cpmxptpt++)[(int)amino_n[(int)*seqpt++]] += feff;
+			(*cpmxptpt++)[(int)amino_n[(unsigned char)*seqpt++]] += feff;
 	}
 #if 0
 	for( j=0; j<lgth; j++ ) for( i=0; i<nalphabets; i++ ) cpmx[j][i] = 0.0;
@@ -253,8 +253,8 @@ void cpmx_ribosum( char **seq, char **seqr, char *dir, double **cpmx, double *ef
 			else
 				code = code1;
 #else
-			code1 = amino_n[(int)*seqpt];
-			code2 = amino_n[(int)*seqrpt];
+			code1 = amino_n[(unsigned char)*seqpt];
+			code2 = amino_n[(unsigned char)*seqrpt];
 			if( code1 > 3 ) 
 			{
 				code = 36;
