@@ -9,9 +9,10 @@
 #include "mltaln.h"
 
 
+#define FULLSCORE 0
+
 #define DEBUG 0
 #define RECORD 0
-#define MCD 0
 
 extern char **seq_g;
 extern char **res_g;
@@ -46,7 +47,7 @@ typedef struct _threadarg
 	int alloclen;
 	Node *stopol;
 	int ***topol;
-//	double **len;
+	double **len;
 	double **tscorehistory_detail;
 	int *finishpt;
 	int **skipthisbranch;
@@ -100,21 +101,40 @@ static void classifypairs( int n1, double **eff1s, double *eff1, int n2, double
 		for( j=0; j<n2; j++ ) eff2s[c][j] = 0.0;
 	}
 	
-//	fprintf( stderr, "\n" );
+#if 0
+	for( i=0; i<n1; i++ ) for( j=0; j<n2; j++ )
+	{
+		c = (int)( smalldistmtx[i][j] / 2.0 * ndistclass ); // dist:0..2
+//		if( c >= ndistclass ) c = ndistclass-1;
+		if( c >= maxdistclass ) c = maxdistclass-1;
+		fprintf( stderr, "pair %d-%d (%f), dist=%f -> c=%d\n", i, j, eff1[i] * eff2[j], smalldistmtx[i][j], c );
+		eff1s[c][i] += 1.0;
+		eff2s[c][j] += 1.0;
+		matnum[i][j] = c;
+	}
+	for( c=0; c<maxdistclass; c++ ) for( i=0; i<n1; i++ ) if(eff1s[c][i]) eff1s[c][i] = eff1[i]/eff1s[c][i];
+	for( c=0; c<maxdistclass; c++ ) for( i=0; i<n2; i++ ) if(eff2s[c][i]) eff2s[c][i] = eff2[i]/eff2s[c][i];
+#else
 	for( i=0; i<n1; i++ ) for( j=0; j<n2; j++ )
 	{
 		c = (int)( smalldistmtx[i][j] / 2.0 * ndistclass ); // dist:0..2
 //		if( c >= ndistclass ) c = ndistclass-1;
 		if( c >= maxdistclass ) c = maxdistclass-1;
 //		fprintf( stderr, "pair %d-%d (%f), dist=%f -> c=%d\n", i, j, eff1[i] * eff2[j], smalldistmtx[i][j], c );
-		eff1s[c][i] = 1.0;
-		eff2s[c][j] = 1.0;
+		eff1s[c][i] = eff1[i];
+		eff2s[c][j] = eff2[j];
 		matnum[i][j] = c;
 	}
-	for( c=0; c<maxdistclass; c++ ) for( i=0; i<n1; i++ ) eff1s[c][i] *= eff1[i];
-	for( c=0; c<maxdistclass; c++ ) for( i=0; i<n2; i++ ) eff2s[c][i] *= eff2[i];
+#endif
 #if 0
 	double totaleff;
+	for( i=0; i<n1; i++ ) for( j=0; j<n2; j++ ) reporterr( "whichmtx[%d][%d] = %d\n", i, j, matnum[i][j] );
+	for( c=0; c<maxdistclass; c++ ) 
+	{
+		totaleff = 0.0; 
+		for( i=0; i<n1; i++ ) for( j=0; j<n2; j++ ) totaleff += eff1s[c][i] * eff2s[c][j];
+		fprintf( stderr, "c=%d, sum totaleff1s-2s  = %f\n", c, totaleff );
+	}
 	totaleff = 0.0; for( c=0; c<maxdistclass; c++ ) for( i=0; i<n1; i++ ) for( j=0; j<n2; j++ ) totaleff += eff1s[c][i] * eff2s[c][j];
 	fprintf( stderr, "totaleff1s-2s  = %f\n", totaleff );
 	totaleff = 0.0; for( i=0; i<n1; i++ ) for( j=0; j<n2; j++ ) totaleff += eff1[i] * eff2[j];
@@ -128,11 +148,13 @@ static void classifypairs( int n1, double **eff1s, double *eff1, int n2, double
 	fprintf( stderr, "totaleff1 = %f\n", totaleff );
 	totaleff = 0.0; for( i=0; i<n2; i++ ) totaleff += eff2[i]; 
 	fprintf( stderr, "totaleff2 = %f\n", totaleff );
+	for( c=0; c<maxdistclass; c++ )
 	{
-//		for( i=0; i<n1; i++ ) fprintf( stderr, "eff1s[%d][%d] = %f\n", c, i, eff1s[c][i] );
-//		for( i=0; i<n2; i++ ) fprintf( stderr, "eff2s[%d][%d] = %f\n", c, i, eff2s[c][i] );
-//		fprintf( stderr, "\n" );
+		for( i=0; i<n1; i++ ) fprintf( stderr, "eff1s[%d][%d] = %f\n", c, i, eff1s[c][i] );
+		for( i=0; i<n2; i++ ) fprintf( stderr, "eff2s[%d][%d] = %f\n", c, i, eff2s[c][i] );
+		fprintf( stderr, "\n" );
 	}
+exit( 1 );
 #endif
 }
 
@@ -229,6 +251,7 @@ static void freelocalarrays(
 	RNApair ***grouprna1, RNApair ***grouprna2,
 	RNApair *rnapairboth,
 	char *indication1, char *indication2,
+	double *distarr,
 	double *effarr, double *effarrforlocalhom, double *effarr1, double *effarr2,
 	char **mseq1, char **mseq2,
 	char **localcopy,
@@ -238,9 +261,6 @@ static void freelocalarrays(
 	char *pairbuf,
 	LocalHom *** localhomshrink,
 	double **smalldistmtx,
-#if MCD
-	double **offsetmtx,
-#endif
 	double ***scoringmatrices,
 	double **eff1s, double **eff2s,
 	int **whichmtx
@@ -253,22 +273,27 @@ static void freelocalarrays(
 	commonIP = NULL;
 	Falign( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, NULL );
 	Falign_localhom( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL,NULL, 0, NULL );
+	D__align( NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, 0, 0 );
+	partA__align_variousdist( NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, 0, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL );
+
+
 	if( rnakozo && rnaprediction == 'm' )
 	{
 		free( grouprna1 ); // nakamimo?
 		free( grouprna2 ); // nakamimo?
 	}
 
-	free( tscorehistory );
+	if( tscorehistory ) free( tscorehistory );
 	free( indication1 );
 	free( indication2 );
+	free( distarr );
 	free( effarr );
 	free( effarrforlocalhom );
 	free( effarr1 );
 	free( effarr2 );
 	free( mseq1 );
 	free( mseq2 );
-	FreeCharMtx( localcopy );
+	if( localcopy ) FreeCharMtx( localcopy );
 	free( gapmap1 );
 	free( gapmap2 );
 
@@ -280,9 +305,6 @@ static void freelocalarrays(
 	free( pairbuf );
 
 	if( smalldistmtx ) FreeDoubleMtx( smalldistmtx );
-#if MCD
-	if( offsetmtx ) FreeDoubleMtx( offsetmtx );
-#endif
 	if( scoringmatrices ) FreeDoubleCub( scoringmatrices );
 	if( eff1s ) FreeDoubleMtx( eff1s );
 	if( eff2s ) FreeDoubleMtx( eff2s );
@@ -329,7 +351,7 @@ static void *athread( void *arg )
 	int alloclen = targ->alloclen;
 	Node * stopol = targ->stopol;
 	int ***topol = targ->topol;
-//	double **len = targ->len;
+	double **len = targ->len;
 	double **tscorehistory_detail = targ->tscorehistory_detail;
 	int *finishpt = targ->finishpt;
 	int **skipthisbranch = targ->skipthisbranch;
@@ -345,6 +367,7 @@ static void *athread( void *arg )
 	int clus1, clus2;
 	char **localcopy;
 	char **mseq1, **mseq2;
+	double *distarr; // re-calc 
 	double *effarr, *effarr_kozo; // re-calc 
 	double *effarr1, *effarr2, *effarr1_kozo, *effarr2_kozo;
 	char *indication1, *indication2;
@@ -375,9 +398,6 @@ static void *athread( void *arg )
 	int converged2 = 0;
 	int chudanres;
 	double **smalldistmtx;
-#if MCD
-	double **offsetmtx = NULL; // check senyou
-#endif
 	double ***scoringmatrices;
 	double **eff1s, **eff2s; 
 	int **whichmtx;
@@ -421,6 +441,7 @@ static void *athread( void *arg )
 
 	indication1 = AllocateCharVec( 150 );
 	indication2 = AllocateCharVec( 150 );
+	distarr = AllocateDoubleVec( locnjob );
 	effarr = AllocateDoubleVec( locnjob );
 	effarrforlocalhom = AllocateDoubleVec( locnjob );
 	effarr1 = AllocateDoubleVec( locnjob );
@@ -433,9 +454,6 @@ static void *athread( void *arg )
 	if( specificityconsideration != 0 ) 
 	{
 		smalldistmtx = AllocateDoubleMtx( locnjob, locnjob ); // ookii?
-#if MCD
-		offsetmtx = AllocateDoubleMtx( locnjob, locnjob ); // ookii?
-#endif
 		scoringmatrices = AllocateDoubleCub( maxdistclass, nalphabets, nalphabets );
 		makescoringmatrices( scoringmatrices, n_dis_consweight_multi );
 		eff1s = AllocateDoubleMtx( maxdistclass, locnjob );
@@ -445,9 +463,6 @@ static void *athread( void *arg )
 	else
 	{
 		smalldistmtx = NULL;
-#if MCD
-		offsetmtx = NULL;
-#endif
 		scoringmatrices = NULL;
 		eff1s = eff2s = NULL;
 		whichmtx = NULL;
@@ -509,6 +524,7 @@ static void *athread( void *arg )
 					grouprna1, grouprna2,
 					rnapairboth,
 					indication1, indication2,
+					distarr,
 					effarr, effarrforlocalhom, effarr1, effarr2,
 					mseq1, mseq2,
 					localcopy,
@@ -517,9 +533,6 @@ static void *athread( void *arg )
 					memlist, pairbuf,
 					localhomshrink,
 					smalldistmtx,
-#if MCD
-					offsetmtx,
-#endif
 					scoringmatrices,
 					eff1s, eff2s,
 					whichmtx
@@ -628,6 +641,7 @@ static void *athread( void *arg )
 			grouprna1, grouprna2,
 			rnapairboth,
 			indication1, indication2,
+			distarr,
 			effarr, effarrforlocalhom, effarr1, effarr2,
 			mseq1, mseq2,
 			localcopy,
@@ -636,9 +650,6 @@ static void *athread( void *arg )
 			memlist, pairbuf,
 			localhomshrink,
 			smalldistmtx,
-#if MCD
-			offsetmtx,
-#endif
 			scoringmatrices,
 			eff1s, eff2s,
 			whichmtx
@@ -675,6 +686,7 @@ static void *athread( void *arg )
 					grouprna1, grouprna2,
 					rnapairboth,
 					indication1, indication2,
+					distarr,
 					effarr, effarrforlocalhom, effarr1, effarr2,
 					mseq1, mseq2,
 					localcopy,
@@ -683,9 +695,6 @@ static void *athread( void *arg )
 					memlist, pairbuf,
 					localhomshrink,
 					smalldistmtx,
-#if MCD
-					offsetmtx,
-#endif
 					scoringmatrices,
 					eff1s, eff2s,
 					whichmtx
@@ -729,7 +738,8 @@ static void *athread( void *arg )
 #endif
 
 //			for( i=0; i<2; i++ ) for( j=0; j<locnjob; j++ ) pair[i][j] = 0;
-			OneClusterAndTheOther_fast( locnjob, memlist[0], memlist[1], &s1, &s2, pairbuf, topol, l, k, smalldistmtx, distmtx );
+			distFromABranch( locnjob, distarr, stopol, topol, len, l, k ); // ato de idou
+			OneClusterAndTheOther_fast( locnjob, memlist[0], memlist[1], &s1, &s2, pairbuf, topol, l, k, smalldistmtx, distmtx, distarr );
 
 
 //			reporterr( "\n\n\n\n##### memlist[0][0], memlist[1][0] = %d, %d\n", memlist[0][0]+1, memlist[1][0]+1 );
@@ -763,6 +773,7 @@ static void *athread( void *arg )
 			}
 			else if( weight == 4 )
 			{
+
 				weightFromABranch( locnjob, effarr, stopol, topol, l, k );
 				if( nkozo ) // hitomadu single weight.
 				{
@@ -825,18 +836,12 @@ static void *athread( void *arg )
 			if( smalldistmtx )
 			{
 				classifypairs( clus1, eff1s, effarr1, clus2, eff2s, effarr2, smalldistmtx, whichmtx, maxdistclass );
-#if MCD
-				for( i=0; i<clus1; i++ )for( j=0; j<clus2; j++ )
-				{
-//					offsetmtx[i][j] = dist2offset( smalldistmtx[i][j] );
-//					int digit = (int)( smalldistmtx[i][j] / 2.0 * (double)ndistclass );
-//					fprintf( stderr, "digit = %d\n", digit );
-//					offsetmtx[i][j] = dist2offset( (double)digit * 2.0 / ndistclass );
+			}
 
-					offsetmtx[i][j] = dist2offset( smalldistmtx[i][j] );
-//					fprintf( stderr, "offsetmtx[%d][%d] = %f -> %f\n", i, j, smalldistmtx[i][j], offsetmtx[i][j] );
-				}
-#endif
+			if( alg == 'd' ) // Ichijiteki, koredeha scorecheck ga dekinai. gapmap ni taiou surumade
+			{
+				commongappick( clus1, mseq1 );
+				commongappick( clus2, mseq2 );
 			}
 
 			if( score_check == 2 )
@@ -864,6 +869,16 @@ static void *athread( void *arg )
 							fprintf( stderr, "'Q' is no longer supported\n" );
 							exit( 1 );
 						}
+						else if( alg == 'd' )
+						{
+							imp_match_init_strictD( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
+							if( rnakozo ) imp_rnaD( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
+							for(  i=length-1; i>=0; i-- )
+							{
+								oimpmatchdouble += (double)imp_match_out_scD( i, i );
+//								fprintf( stderr, "#### i=%d, initial impmatch = %f seq1 = %c, seq2 = %c\n", i, oimpmatch, mseq1[0][i], mseq2[0][i] );
+							}
+						}
 						else
 						{
 							part_imp_match_init_strict( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
@@ -933,6 +948,7 @@ static void *athread( void *arg )
 //			if( rnakozo ) foldalignedrna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, rnapairboth );
 
 //			if( !use_fft && !rnakozo )
+//			if( !use_fft )
 			if( !use_fft )
 			{
 				commongappick_record( clus1, mseq1, gapmap1 );
@@ -970,7 +986,11 @@ static void *athread( void *arg )
 //						else
 //							part_imp_match_init_strict( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
 						chudanres = 0;
-						Falign_localhom( NULL, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatchdouble, gapmap1, gapmap2, subgenerationpt, subgenerationatfirst, &chudanres );
+						if( alg == 'd' )
+							D__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, localhomshrink, &impmatchdouble, NULL, NULL, NULL, NULL, subgenerationpt, subgenerationatfirst, &chudanres, 1, 1 );
+						
+						else
+							Falign_localhom( whichmtx, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatchdouble, gapmap1, gapmap2, subgenerationpt, subgenerationatfirst, &chudanres );
 //						fprintf( stderr, "##### impmatch = %f\n", impmatch );
 						if( chudanres && parallelizationstrategy == BAATARI2 )
 						{
@@ -986,14 +1006,19 @@ static void *athread( void *arg )
 				}
 				else if( use_fft )
 				{
-					double totalwm;
-					chudanres = 0;
-//					totalwm = Falign( smalldistmtx, NULL, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, alloclen, &intdum, subgenerationpt, subgenerationatfirst, &chudanres );
-#if MCD
-					totalwm = Falign( offsetmtx, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, &intdum, subgenerationpt, subgenerationatfirst, &chudanres );
-#else
-					totalwm = Falign( NULL, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, &intdum, subgenerationpt, subgenerationatfirst, &chudanres );
+#if 0
+					if( alg == 'd' )
+					{
+						D__align_variousdist( whichmtx, scoringmatrices, NULL, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, subgenerationpt, subgenerationatfirst, &chudanres, 1, 1 );
+					}
+					else
 #endif
+					{
+						double totalwm;
+						chudanres = 0;
+//						totalwm = Falign( smalldistmtx, NULL, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, NULL, NULL, clus1, clus2, alloclen, &intdum, subgenerationpt, subgenerationatfirst, &chudanres );
+						totalwm = Falign( whichmtx, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, &intdum, subgenerationpt, subgenerationatfirst, &chudanres );
+					}
 					if( chudanres && parallelizationstrategy == BAATARI2 )
 					{
 //						fprintf( stderr, "#### yarinaoshi!!! FFT-NS-i\n" );
@@ -1109,6 +1134,7 @@ static void *athread( void *arg )
 					goto yarinaoshi;
 				}
 #endif
+//				reporterr( "tscore = %f, mscore = %f\n", tscore, mscore );
 				gain = tscore - ( mscore - cut/100.0*mscore );
 				if( gain > 0 )
 				{
@@ -1161,6 +1187,17 @@ static void *athread( void *arg )
 					tscore = mscore;
 				}
 			}
+#if FULLSCORE
+			{
+				int j;
+				double fullscore = 0.0;
+				for( i=1; i<locnjob; i++ ) for( j=0; j<i; j++ )
+					fullscore += (double)naivepairscore11( localcopy[i], localcopy[j], penalty );
+				reporterr( "\n######## fullscore = %f\n", fullscore / (locnjob*(locnjob-1)/2) );
+			}
+#endif
+
+
 			converged2 = 0;
 			for( ii=iterate-2; ii>=0; ii-=1 ) 
 			{
@@ -1215,6 +1252,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	int s1, s2;
 	static double **imanoten;
 	static Node *stopol;
+	static double *distarr = NULL;
 	static double *effarrforlocalhom = NULL;
 	static double *effarr = NULL;
 	static double *effarr1 = NULL;
@@ -1258,12 +1296,10 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	RNApair ***grouprna1, ***grouprna2;
 	double unweightedspscore;
 	static double **smalldistmtx;
-#if MCD
-	static double **offsetmtx = NULL; // check senyou
-#endif
 	static double ***scoringmatrices;
 	static double **eff1s, **eff2s; 
 	static int **whichmtx;
+	int value;
 
 	if( rnakozo && rnaprediction == 'm' )
 	{
@@ -1283,6 +1319,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 		indication1 = AllocateCharVec( 150 );
 		indication2 = AllocateCharVec( 150 );
 		effarr = AllocateDoubleVec( locnjob );
+		distarr = AllocateDoubleVec( locnjob );
 		effarrforlocalhom = AllocateDoubleVec( locnjob );
 		effarr1 = AllocateDoubleVec( locnjob );
 		effarr2 = AllocateDoubleVec( locnjob );
@@ -1300,9 +1337,6 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 		if( specificityconsideration != 0 ) 
 		{
 			smalldistmtx = AllocateDoubleMtx( locnjob, locnjob ); // ookii?
-#if MCD
-			offsetmtx = AllocateDoubleMtx( locnjob, locnjob ); // ookii?
-#endif
 			scoringmatrices = AllocateDoubleCub( maxdistclass, nalphabets, nalphabets );
 			makescoringmatrices( scoringmatrices, n_dis_consweight_multi );
 			eff1s = AllocateDoubleMtx( maxdistclass, locnjob );
@@ -1312,9 +1346,6 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 		else
 		{
 			smalldistmtx = NULL;
-#if MCD
-			offsetmtx = NULL;
-#endif
 			scoringmatrices = NULL;
 			eff1s = eff2s = NULL;
 			whichmtx = NULL;
@@ -1448,7 +1479,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 			targ[i].topol = topol;
 			targ[i].skipthisbranch = skipthisbranch;
 			targ[i].distmtx = distmtx;
-//			targ[i].len = len;
+			targ[i].len = len;
 			targ[i].mutex = &mutex;
 			targ[i].collection_end = &collection_end;
 			targ[i].collection_start = &collection_start;
@@ -1631,8 +1662,11 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 						continue;
 					}
 
+					distFromABranch( locnjob, distarr, stopol, topol, len, l, k ); // ato de dou. weight 4 igai demo tsukaeruyou ni.
+					for( i=0; i<locnjob; i++ )
 //					for( i=0; i<2; i++ ) for( j=0; j<locnjob; j++ ) pair[i][j] = 0;
-					OneClusterAndTheOther_fast( locnjob, memlist[0], memlist[1], &s1, &s2, pairbuf, topol, l, k, smalldistmtx, distmtx );
+					OneClusterAndTheOther_fast( locnjob, memlist[0], memlist[1], &s1, &s2, pairbuf, topol, l, k, smalldistmtx, distmtx, distarr );
+
 
 
 
@@ -1673,7 +1707,9 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 					}
 					else if( weight == 4 )
 					{
+
 						weightFromABranch( locnjob, effarr, stopol, topol, l, k );
+
 	#if 0
 						if( nkozo )
 						{
@@ -1742,18 +1778,16 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 					if( smalldistmtx )
 					{
 						classifypairs( clus1, eff1s, effarr1, clus2, eff2s, effarr2, smalldistmtx, whichmtx, maxdistclass );
-#if MCD
-						for( i=0; i<clus1; i++ )for( j=0; j<clus2; j++ )
-						{
-							offsetmtx[i][j] = dist2offset( smalldistmtx[i][j] );
-//							fprintf( stderr, "offsetmtx[%d][%d] = %f -> %f\n", i, j, smalldistmtx[i][j], offsetmtx[i][j] );
-//							smalldistmtx[i][j] = smalldistmtx[i][j] * 1.0 - specificityconsideration;
-//							if( smalldistmtx[i][j] > 0 ) smalldistmtx[i][j] = 0.0;
-//							fprintf( stderr, "offset[%d][%d] = %f\n", i, j, smalldistmtx[i][j] );
-						}
-#endif
 					}
 
+					if( alg == 'd' ) // Ichijiteki, koredeha scorecheck ga dekinai. gapmap ni taiou surumade
+					{
+						commongappick( clus1, mseq1 );
+						commongappick( clus2, mseq2 );
+					}
+
+
+
 					if( score_check == 2 )
 					{
 						fprintf( stderr, "Not supported\n" );
@@ -1852,6 +1886,16 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 									fprintf( stderr, "'Q' is no longer supported\n" );
 									exit( 1 );
 								}
+								else if( alg == 'd' )
+								{
+									imp_match_init_strictD( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
+	
+									for(  i=length-1; i>=0; i-- )
+									{
+										oimpmatchdouble += (double)imp_match_out_scD( i, i );
+		//								fprintf( stderr, "#### i=%d, initial impmatch = %f seq1 = %c, seq2 = %c\n", i, oimpmatch, mseq1[0][i], mseq2[0][i] );
+									}
+								}
 								else
 								{
 									part_imp_match_init_strict( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
@@ -1912,11 +1956,15 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 					}
 					else
 					{
-	//					fprintf( stderr, "score_check = %d\n", score_check );
-	/* atode kousokuka */
+//						fprintf( stderr, "score_check = %d\n" );
+#if 1
+	/* Oscilation check no tame hitsuyou! atode kousokuka */
 						intergroup_score( mseq1, mseq2, effarr1, effarr2, clus1, clus2, length, &tmpdouble );
 						mscore = tmpdouble;
 	/* atode kousokuka */
+#else
+						mscore = 0.0;
+#endif
 	
 						if( constraint )
 						{
@@ -1930,6 +1978,11 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 									fprintf( stderr, "'Q' is no longer supported\n" );
 									exit( 1 );
 								}
+								else if( alg == 'd' )
+								{
+									imp_match_init_strictD( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
+									if( rnakozo ) imp_rnaD( clus1, clus2, mseq1, mseq2, effarr1, effarr2, grouprna1, grouprna2, gapmap1, gapmap2, NULL );
+								}
 								else
 								{
 									part_imp_match_init_strict( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
@@ -1989,6 +2042,7 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	//				if( rnakozo ) foldalignedrna( clus1, clus2, mseq1, mseq2, effarr1, effarr2, rnapairboth );
 	
 	//				if( !use_fft && !rnakozo )
+//					if( !use_fft )
 					if( !use_fft )
 					{
 						commongappick_record( clus1, mseq1, gapmap1 );
@@ -2022,7 +2076,19 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	//							part_imp_match_init_strictQ( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, localhomshrink, 1 );
 	//						else
 	//							part_imp_match_init_strict( NULL, clus1, clus2, length, length, mseq1, mseq2, effarr1, effarr2, effarr1_kozo, effarr2_kozo, localhomshrink, 1 );
-							Falign_localhom( NULL, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatchdouble, gapmap1, gapmap2, NULL, 0, NULL );
+							if( alg == 'd' )
+							{
+								if( scoringmatrices ) // called by tditeration.c 
+								{
+									D__align_variousdist( whichmtx, scoringmatrices, NULL, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatchdouble, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 1 );
+								}
+								else
+								{
+									D__align( n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, clus1, clus2, alloclen, localhomshrink, &impmatchdouble, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 1 );
+								}
+							}
+							else
+								Falign_localhom( whichmtx, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, localhomshrink, &impmatchdouble, gapmap1, gapmap2, NULL, 0, NULL );
 	//						fprintf( stderr, "##### impmatch = %f\n", impmatch );
 						}
 						else
@@ -2034,13 +2100,20 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 					else if( use_fft )
 					{
 						double totalwm;
-#if MCD
-						totalwm = Falign( offsetmtx, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, &intdum, NULL, 0, NULL );
-#else
-						totalwm = Falign( NULL, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, &intdum, NULL, 0, NULL );
+#if 0
+						double dumdb;
+						// D ha Falign wo toshite yobareru.
+						if( alg == 'd' )
+						{
+							D__align_variousdist( whichmtx, scoringmatrices, NULL, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, NULL, &dumdb, NULL, NULL, NULL, NULL, NULL, 0, NULL, 1, 1 );
+						}
+						else
 #endif
+						{
+							totalwm = Falign( whichmtx, scoringmatrices, n_dis_consweight_multi, mseq1, mseq2, effarr1, effarr2, eff1s, eff2s, clus1, clus2, alloclen, &intdum, NULL, 0, NULL );
 	
-	//					fprintf( stderr, "totalwm = %f\n", totalwm );
+	//						fprintf( stderr, "totalwm = %f\n", totalwm );
+						}
 					}
 					else
 					{
@@ -2073,6 +2146,29 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 	
 	
 	/* Bug?  : idnetitcal but score change when scoreing mtx != JTT  */
+#if FULLSCORE
+					{
+						double fullscore = 0.0, fullscoreori = 0.0;
+						for( i=1; i<locnjob; i++ ) for( j=0; j<i; j++ )
+							fullscore += (double)naivepairscore11( aseq[i], aseq[j], penalty );
+						reporterr( "\nfullscore = %f\n", fullscore / (locnjob*(locnjob-1)/2) );
+						for( i=1; i<locnjob; i++ ) for( j=0; j<i; j++ )
+							fullscoreori += (double)naivepairscore11( bseq[i], bseq[j], penalty );
+						reporterr( "\nfullscoreori = %f\n", fullscoreori / (locnjob*(locnjob-1)/2) );
+						if( 0 && fullscoreori > fullscore )
+						{
+							for( i=0; i<clus1; i++ )
+								fprintf( stdout, ">group1\n%s\n", mseq1[i] );
+							for( i=0; i<clus2; i++ )
+								fprintf( stdout, ">group2\n%s\n", mseq2[i] );
+
+
+							for( i=0; i<locnjob; i++ )
+								fprintf( stdout, ">better alignment\n%s\n", bseq[i] );
+							exit( 1 );
+						}
+					}
+#endif
 	
 					length = strlen( mseq1[0] );
 		
@@ -2179,7 +2275,10 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 							converged++;
 						}
 					}
-					fprintf( stderr, "\r" );
+					if( alg == 'd' ) 
+						fprintf( stderr, "\n" );
+					else
+						fprintf( stderr, "\r" );
 	
 	
 					history[iterate][l][k] = (double)tscore;
@@ -2198,9 +2297,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 							if( weight || constraint ) fprintf( stderr, " (differs from the objective score)" );
 							fprintf( stderr, "\n\n" );
 						}
-						if( grouprna1 ) free( grouprna1 );
-						if( grouprna2 ) free( grouprna2 );
-						return( 0 );
+						value = 0;
+						goto end;
 					}
 					if( iterate >= 1 )
 					{
@@ -2227,9 +2325,8 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 								fprintf( stderr, "\n\n" );
 							}
 	#if 1 /* hujuubun */
-							if( grouprna1 ) free( grouprna1 );
-							if( grouprna2 ) free( grouprna2 );
-							return( -1 );
+							value = -1;
+							goto end;
 	#endif
 						}
 					}      /* if( iterate ) */
@@ -2245,7 +2342,31 @@ int TreeDependentIteration( int locnjob, char **name, int nlen[M],
 			}
 		}                  /* for( iterate ) */
 	}
+	value = 2;
+
+	end:
 	if( grouprna1 ) free( grouprna1 );
 	if( grouprna2 ) free( grouprna2 );
-	return( 2 );
+//	freelocalarrays
+//	( 
+//		NULL,
+//		grouprna1, grouprna2,
+//		rnapairboth,
+//		indication1, indication2,
+//		distarr,
+//		effarr, effarrforlocalhom, effarr1, effarr2,
+//		mseq1, mseq2,
+//		NULL,
+//		gapmap1, gapmap2,
+//		effarr1_kozo, effarr2_kozo, effarr_kozo,
+//		memlist, pairbuf,
+//		localhomshrink,
+//		smalldistmtx,
+//		scoringmatrices,
+//		eff1s, eff2s,
+//		whichmtx
+//	);
+//	free( branchnode );
+//	free( stopol );
+	return( value );
 }                  	   /* int Tree... */
